# Greetings by Shiloh6
This is a python package that can say greetings in python.

## Usage
```python
import greetings

# Say hello to any name
greetings.sayHello('Shiloh')

# Say bye to any name
greetings.sayBye('Shiloh)
```